@@ -638,6 +638,7 @@ define([
 
     FrameEditor.prototype.renderRenamePage = function() {
         var content = new sb.StringBuilder();
+        content.appendFormatLine('<div class="{0} {1}">', 'vp-popup-rename-page', 'vp-scrollbar');
         content.appendLine('<table>');
         content.appendLine('<colgroup><col width="100px"><col width="*"></colgroup>');
         this.state.selected.forEach((col, idx) => {
@@ -648,6 +649,7 @@ define([
             content.appendLine('</tr>');
         });
         content.appendLine('</table>');
+        content.appendLine('</div>');
         return content.toString();
     }
 
@@ -655,10 +657,12 @@ define([
         var content = new sb.StringBuilder();
         content.appendFormatLine('<label><input type="checkbox" class="{0}"/><span>{1}</span></label>', 'vp-popup-use-regex', 'Use Regular Expression');
         content.appendLine('<br/><br/>');
-        content.appendFormatLine('<table class="{0}">', 'vp-popup-replace-table');
+        content.appendFormatLine('<div class="{0}">', 'vp-popup-replace-table');
+        content.appendLine('<table>');
         content.appendLine(this.renderReplaceInput(0));
         content.appendFormatLine('<tr><td colspan="3"><button class="{0} {1}">{2}</button></td></tr>', 'vp-button', 'vp-popup-replace-add', '+ Add Key');
         content.appendLine('</table>');
+        content.appendLine('</div>');
         return content.toString();
     }
 
@@ -1170,7 +1174,7 @@ define([
         return code.toString();
     }
     
-    FrameEditor.prototype.loadCode = function(codeStr) {
+    FrameEditor.prototype.loadCode = function(codeStr, more=false) {
         if (this.loading) {
             return;
         }
@@ -1178,77 +1182,126 @@ define([
         var that = this;
         var tempObj = this.state.tempObj;
         var lines = this.state.lines;
+        var prevLines = 0;
+        var scrollPos = -1;
+        if (more) {
+            prevLines = that.state.indexList.length;
+            scrollPos = $(this.wrapSelector('.vp-fe-table')).scrollTop();
+        }
 
         var code = new sb.StringBuilder();
         code.appendLine(codeStr);
-        code.appendFormat("{0}.head({1}).to_json(orient='{2}')", tempObj, lines, 'split');
+        code.appendFormat("{0}[{1}:{2}].to_json(orient='{3}')", tempObj, prevLines, lines, 'split');
         
         this.loading = true;
         kernelApi.executePython(code.toString(), function(result) {
             try {
+                if (!result || result.length <= 0) {
+                    return;
+                }
+                var data = JSON.parse(result.substr(1,result.length - 2).replaceAll('\\\\', '\\'));
+                
                 kernelApi.getColumnList(tempObj, function(columnResult) {
-                    var data = JSON.parse(result.substr(1,result.length - 2).replaceAll('\\\\', '\\'));
                     
                     var columnList = JSON.parse(columnResult);
                     // var columnList = data.columns;
                     var indexList = data.index;
                     var dataList = data.data;
+
+                    columnList = columnList.map(col => { return { label: col.label, type: col.dtype, code: col.value } });
+                    indexList = indexList.map(idx => { return { label: idx, code: idx } });
     
-                    that.state.columnList = columnList.map(col => { return { label: col.label, type: col.dtype, code: col.value } });
-                    that.state.indexList = indexList.map(idx => { return { label: idx, code: idx } });
-    
-                    // table
-                    var table = new sb.StringBuilder();
-                    // table.appendFormatLine('<table border="{0}" class="{1}">', 1, 'dataframe');
-                    table.appendLine('<thead>');
-                    table.appendLine('<tr><th></th>');
-                    that.state.columnList && that.state.columnList.forEach(col => {
-                        var colCode = col.code;
-                        var colClass = '';
-                        if (that.state.axis == FRAME_AXIS.COLUMN && that.state.selected.map(col=>col.code).includes(colCode)) {
-                            colClass = 'selected';
-                        }
-                        table.appendFormatLine('<th data-code="{0}" data-axis="{1}" data-type="{2}" class="{3} {4}">{5}</th>'
-                                                , colCode, FRAME_AXIS.COLUMN, col.type, VP_FE_TABLE_COLUMN, colClass, col.label);
-                    });
-                    // add column
-                    table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_COLUMN, '/nbextensions/visualpython/resource/plus.svg');
-    
-                    table.appendLine('</tr>');
-                    table.appendLine('</thead>');
-                    table.appendLine('<tbody>');
-    
-                    dataList && dataList.forEach((row, idx) => {
-                        table.appendLine('<tr>');
-                        var idxName = that.state.indexList[idx].label;
-                        var idxLabel = convertToStr(idxName, typeof idxName == 'string');
-                        var idxClass = '';
-                        if (that.state.axis == FRAME_AXIS.ROW && that.state.selected.includes(idxLabel)) {
-                            idxClass = 'selected';
-                        }
-                        table.appendFormatLine('<th data-code="{0}" data-axis="{1}" class="{2} {3}">{4}</th>', idxLabel, FRAME_AXIS.ROW, VP_FE_TABLE_ROW, idxClass, idxName);
-                        row.forEach((cell, colIdx) => {
-                            if (cell == null) {
-                                cell = 'NaN';
+                    if (!more) {
+                        // table
+                        var table = new sb.StringBuilder();
+                        // table.appendFormatLine('<table border="{0}" class="{1}">', 1, 'dataframe');
+                        table.appendLine('<thead>');
+                        table.appendLine('<tr><th></th>');
+                        columnList && columnList.forEach(col => {
+                            var colCode = col.code;
+                            var colClass = '';
+                            if (that.state.axis == FRAME_AXIS.COLUMN && that.state.selected.map(col=>col.code).includes(colCode)) {
+                                colClass = 'selected';
                             }
-                            var cellType = that.state.columnList[colIdx].type;
-                            if (cellType.includes('datetime')) {
-                                cell = new Date(parseInt(cell)).toLocaleDateString();
-                            }
-                            table.appendFormatLine('<td>{0}</td>', cell);
+                            table.appendFormatLine('<th data-code="{0}" data-axis="{1}" data-type="{2}" class="{3} {4}">{5}</th>'
+                                                    , colCode, FRAME_AXIS.COLUMN, col.type, VP_FE_TABLE_COLUMN, colClass, col.label);
                         });
-                        // empty data
-                        // table.appendLine('<td></td>');
+                        // add column
+                        table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_COLUMN, '/nbextensions/visualpython/resource/plus.svg');
+        
                         table.appendLine('</tr>');
-                    });
-                    // add row
-                    table.appendLine('<tr>');
-                    table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_ROW, '/nbextensions/visualpython/resource/plus.svg');
-                    table.appendLine('</tbody>');
-                    table.appendLine('</tr>');
-                    $(that.wrapSelector('.' + VP_FE_TABLE)).replaceWith(function() {
-                        return that.renderTable(table.toString());
-                    });
+                        table.appendLine('</thead>');
+                        table.appendLine('<tbody>');
+        
+                        dataList && dataList.forEach((row, idx) => {
+                            table.appendLine('<tr>');
+                            var idxName = indexList[idx].label;
+                            var idxLabel = convertToStr(idxName, typeof idxName == 'string');
+                            var idxClass = '';
+                            if (that.state.axis == FRAME_AXIS.ROW && that.state.selected.includes(idxLabel)) {
+                                idxClass = 'selected';
+                            }
+                            table.appendFormatLine('<th data-code="{0}" data-axis="{1}" class="{2} {3}">{4}</th>', idxLabel, FRAME_AXIS.ROW, VP_FE_TABLE_ROW, idxClass, idxName);
+                            row.forEach((cell, colIdx) => {
+                                if (cell == null) {
+                                    cell = 'NaN';
+                                }
+                                var cellType = columnList[colIdx].type;
+                                if (cellType.includes('datetime')) {
+                                    cell = new Date(parseInt(cell)).toLocaleString();
+                                }
+                                table.appendFormatLine('<td>{0}</td>', cell);
+                            });
+                            // empty data
+                            // table.appendLine('<td></td>');
+                            table.appendLine('</tr>');
+                        });
+                        // add row
+                        table.appendLine('<tr>');
+                        table.appendFormatLine('<th class="{0}"><img src="{1}"/></th>', VP_FE_ADD_ROW, '/nbextensions/visualpython/resource/plus.svg');
+                        table.appendLine('</tr>');
+                        table.appendLine('</tbody>');
+                        $(that.wrapSelector('.' + VP_FE_TABLE)).replaceWith(function() {
+                            return that.renderTable(table.toString());
+                        });
+                    } else {
+                        var table = new sb.StringBuilder();
+                        dataList && dataList.forEach((row, idx) => {
+                            table.appendLine('<tr>');
+                            var idxName = indexList[idx].label;
+                            var idxLabel = convertToStr(idxName, typeof idxName == 'string');
+                            var idxClass = '';
+                            if (that.state.axis == FRAME_AXIS.ROW && that.state.selected.includes(idxLabel)) {
+                                idxClass = 'selected';
+                            }
+                            table.appendFormatLine('<th data-code="{0}" data-axis="{1}" class="{2} {3}">{4}</th>', idxLabel, FRAME_AXIS.ROW, VP_FE_TABLE_ROW, idxClass, idxName);
+                            row.forEach((cell, colIdx) => {
+                                if (cell == null) {
+                                    cell = 'NaN';
+                                }
+                                var cellType = columnList[colIdx].type;
+                                if (cellType.includes('datetime')) {
+                                    cell = new Date(parseInt(cell)).toLocaleString();
+                                }
+                                table.appendFormatLine('<td>{0}</td>', cell);
+                            });
+                            // empty data
+                            // table.appendLine('<td></td>');
+                            table.appendLine('</tr>');
+                        });
+                        // insert before last tr tag(add row button)
+                        $(table.toString()).insertBefore($(that.wrapSelector('.' + VP_FE_TABLE + ' tbody tr:last')));
+                    }
+
+                    // save columnList & indexList as state
+                    that.state.columnList = columnList;
+                    if (!more) {
+                        that.state.indexList = indexList;
+                    } else {
+                        that.state.indexList = that.state.indexList.concat(indexList);
+                    }
+
+
                     // load info
                     that.loadInfo();
                     // add to stack
@@ -1257,6 +1310,11 @@ define([
                         var replacedCode = codeStr.replaceAll(that.state.tempObj, that.state.returnObj);
                         that.setPreview(replacedCode);
                     }
+                    
+                    // if scrollPos is saved, go to the position
+                    if (scrollPos >= 0) {
+                        $(that.wrapSelector('.vp-fe-table')).scrollTop(scrollPos);
+                    }
     
                     that.loading = false;
                 });
@@ -1376,6 +1434,11 @@ define([
             that.state.tempObj = '_vp';
             that.initState();
 
+            // reset table
+            $(that.wrapSelector('.' + VP_FE_TABLE)).replaceWith(function() {
+                return that.renderTable('');
+            });
+
             // load code with temporary df
             that.loadCode(that.getTypeCode(FRAME_EDIT_TYPE.INIT));
             that.loadInfo();
@@ -1592,7 +1655,7 @@ define([
         // more rows
         $(document).on('click', this.wrapSelector('.' + VP_FE_TABLE_MORE), function() {
             that.state.lines += TABLE_LINES;
-            that.loadCode(that.getTypeCode(FRAME_EDIT_TYPE.SHOW));
+            that.loadCode(that.getTypeCode(FRAME_EDIT_TYPE.SHOW), true);
         });
 
         // click toolbar item
