@@ -17,14 +17,14 @@ define([
     'nbextensions/visualpython/src/common/StringBuilder',
     'nbextensions/visualpython/src/common/vpCommon',
     'nbextensions/visualpython/src/common/kernelApi',
-    'nbextensions/visualpython/src/common/component/vpColumnSelector',
+    'nbextensions/visualpython/src/common/component/vpMultiSelector',
 
     'codemirror/lib/codemirror',
     'codemirror/mode/python/python',
     'notebook/js/codemirror-ipython',
     'codemirror/addon/display/placeholder',
     'codemirror/addon/display/autorefresh'
-], function (vpConst, sb, vpCommon, kernelApi, vpColumnSelector, codemirror) {   
+], function (vpConst, sb, vpCommon, kernelApi, vpMultiSelector, codemirror) {   
 
     //========================================================================
     // Define variable
@@ -305,7 +305,7 @@ define([
             // groupby column
             page.appendLine('<div>');
             page.appendFormatLine('<label for="{0}" class="{1}">{2}</label>', 'vp_gbBy', 'vp-orange-text wp80', 'Groupby');
-            page.appendFormatLine('<input type="text" id="{0}" placeholder="{1}" disabled/>', 'vp_gbBy', 'Groupby coluns');
+            page.appendFormatLine('<input type="text" id="{0}" placeholder="{1}" disabled/>', 'vp_gbBy', 'Groupby columns');
             page.appendFormatLine('<button id="{0}" class="{1}">{2}</button>', 'vp_gbBySelect', 'vp-button wp50', 'Edit');
             page.appendFormatLine('<label><input type="checkbox" id="{0}" disabled/><span>{1}</span></label>', 'vp_gbByGrouper', 'Grouper');
             page.appendFormatLine('<div class="{0}" style="display:none;">', 'vp-gb-by-grouper-box');
@@ -358,7 +358,6 @@ define([
             page.appendLine('<div>');
             page.appendFormatLine('<label for="{0}" class="{1}">{2}</label>', 'vp_gbAllocateTo', 'wp80', 'Allocate to');
             page.appendFormatLine('<input type="text" id="{0}" placeholder="{1}"/>', 'vp_gbAllocateTo', 'New variable name');
-            
             page.appendLine('</div>');
             
             page.appendLine('</div>'); // end of df-box
@@ -480,12 +479,15 @@ define([
         }
 
         /**
-         * Render column selector using ColumnSelector module
+         * Render column selector using MultiSelector module
          * @param {Array<string>} previousList previous selected columns
          * @param {Array<string>} includeList columns to include 
          */
-        renderColumnSelector(previousList, includeList) {
-            this.popup.ColSelector = new vpColumnSelector(this._wrapSelector('.' + APP_POPUP_BODY), this.state.variable, previousList, includeList);
+        renderMultiSelector(previousList, includeList) {
+            this.popup.ColSelector = new vpMultiSelector(
+                this._wrapSelector('.' + APP_POPUP_BODY), 
+                { mode: 'columns', parent: [this.state.variable], selectedList: previousList, includeList: includeList }
+            );
         }
 
         /**
@@ -539,7 +541,7 @@ define([
             if (previousList) {
                 previousList = previousList.map(col => col.code)
             }
-            this.renderColumnSelector(previousList, includeList);
+            this.renderMultiSelector(previousList, includeList);
     
             // set title
             $(this._wrapSelector('.' + APP_POPUP_BOX + ' .' + APP_TITLE)).text(title);
@@ -660,6 +662,8 @@ define([
                     $(that._wrapSelector('#vp_gbBy')).val('');
                     $(that._wrapSelector('#vp_gbDisplay')).val('');
                     that.state.variable = newVal;
+                    that.state.groupby = [];
+                    that.state.display = [];
                 }
             });
 
@@ -670,11 +674,11 @@ define([
 
             // groupby change event
             $(document).on('change', this._wrapSelector('#vp_gbBy'), function(event) {
-                var colList = event.colList;
+                var colList = event.dataList;
                 that.state.groupby = colList;
                 
                 if (colList && colList.length == 1
-                    && colList[0].dtype.includes('datetime')) {
+                    && colList[0].type.includes('datetime')) {
                     $(that._wrapSelector('#vp_gbByGrouper')).removeAttr('disabled');
                 } else {
                     $(that._wrapSelector('#vp_gbByGrouper')).attr('disabled', true);
@@ -710,7 +714,7 @@ define([
 
             // display change event
             $(document).on('change', this._wrapSelector('#vp_gbDisplay'), function(event) {
-                var colList = event.colList;
+                var colList = event.dataList;
                 that.state.display = colList;
             });
 
@@ -768,7 +772,7 @@ define([
 
             // advanced item - column change event
             $(document).on('change', this._wrapSelector('.vp-gb-adv-col'), function(event) {
-                var colList = event.colList;
+                var colList = event.dataList;
                 var idx = $(that._wrapSelector('.vp-gb-adv-col')).index(this);
                 
                 // if there's change, reset display namings
@@ -927,11 +931,11 @@ define([
             $(document).on('click', this._wrapSelector('.' + APP_POPUP_OK), function() {
                 // ok input popup
                 if (that.popup.type == 'column') {
-                    var colList = that.popup.ColSelector.getColumnList();
+                    var dataList = that.popup.ColSelector.getDataList();
     
-                    $(that.popup.targetSelector).val(colList.map(col => { return col.code }).join(','));
-                    $(that.popup.targetSelector).data('list', colList);
-                    $(that.popup.targetSelector).trigger({ type: 'change', colList: colList });
+                    $(that.popup.targetSelector).val(dataList.map(col => { return col.code }).join(','));
+                    $(that.popup.targetSelector).data('list', dataList);
+                    $(that.popup.targetSelector).trigger({ type: 'change', dataList: dataList });
                     that.closeInnerPopup();
                 } else {
                     var dict = {};
