@@ -152,7 +152,7 @@ define([
 
             // title
             page.appendFormat('<div class="{0}">{1}</div>',
-                VP_PDF_TITLE, 'PyMuPDF - Extract text from pdf');
+                VP_PDF_TITLE, 'Extract text from PDF');
 
             // close button
             page.appendFormatLine('<div class="{0}"><img src="{1}"/></div>',
@@ -396,7 +396,7 @@ define([
             if (this.pageThis) {
                 $(this.pageThis.wrapSelector('#' + this.targetId)).val(code);
                 $(this.pageThis.wrapSelector('#' + this.targetId)).trigger({
-                    type: 'pdf_run',
+                    type: 'apps_run',
                     title: 'PDF',
                     code: code,
                     state: this.state,
@@ -406,7 +406,7 @@ define([
             } else {
                 $(vpCommon.wrapSelector('#' + this.targetId)).val(code);
                 $(vpCommon.wrapSelector('#' + this.targetId)).trigger({
-                    type: 'pdf_run',
+                    type: 'apps_run',
                     title: 'PDF',
                     code: code,
                     state: this.state,
