@@ -4,8 +4,8 @@ define ([
 ], function( vpCommon, sb ) {
 
     var _renderAdditionalOptionContainer = function(numpyPageRendererThis) {
-        var uuid = vpCommon.getUUID();
-        var newUuid = vpCommon.getUUID();
+        var uuid = 'u' + vpCommon.getUUID();
+        var newUuid = 'u' + vpCommon.getUUID();
 
         var numpyPageRendererThis = numpyPageRendererThis;
         var importPackageThis = numpyPageRendererThis.getImportPackageThis();
