@@ -8,7 +8,7 @@ define ([
      * @param {numpyPageRenderer this} numpyPageRendererThis 
      */
     var _renderSelectAxisBlock = function(numpyPageRendererThis) {
-        var uuid = vpCommon.getUUID();
+        var uuid = 'u' + vpCommon.getUUID();
         var numpyPageRendererThis = numpyPageRendererThis;
         var importPackageThis = numpyPageRendererThis.getImportPackageThis();
         var numpyStateGenerator = numpyPageRendererThis.getStateGenerator();
@@ -17,29 +17,6 @@ define ([
         var optionPageSelector = numpyPageRendererThis.getOptionPageSelector();
         var optionPage = $(numpyPageRendererThis.importPackageThis.wrapSelector(optionPageSelector));
 
-        /**
-         *  indexNBlock
-         *  Axis 편집 동적 태그 블럭
-         */
-        // var indexNBlock = $(`<div class='vp-numpy-option-block vp-spread' id='vp_blockArea'
-        //                           style='padding-top: 10px;'>
-        //                         <table style='width: 100%;'>
-        //                             <tr>
-        //                                 <td style='width: 40%;'>
-        //                                     <label class='vp-multilang' data-caption-id='Select Axis'
-        //                                            style='margin-bottom: 0px;'> 
-        //                                         Select Axis
-        //                                     </label>
-        //                                 </td>
-                                        
-        //                                 <td>
-        //                                     <select class='vp-numpy-select-indexN' id='vp_numpyIndexN-${uuid}'>
-        //                                     </select>
-        //                                 </td>
-        //                             </tr>
-        //                         </table>
-
-        //                     </div>`);
         var sbTagString = new sb.StringBuilder();
         sbTagString.appendLine( `<tr class='vp-numpy-option-block'>`);
         sbTagString.appendLine(`<th>Select Axis</th>`)
